==> agrosyst-cli-1.4.6-sources.jar: fr/inra/agrosyst/services/pz0import/action/ActionImportDto.java <==
package fr.inra.agrosyst.services.pz0import.action;

/*
 * #%L
 * Agrosyst :: Command Line Interface
 * $Id: ActionImportDto.java 4775 2015-02-10 15:13:34Z dcosse $
 * $HeadURL: https://svn.codelutin.com/agrosyst/tags/1.4.6/agrosyst-cli/src/main/java/fr/inra/agrosyst/services/pz0import/action/ActionImportDto.java $
 * %%
 * Copyright (C) 2013 - 2015 INRA
 * %%
 * INRA - Tous droits réservés
 * #L%
 */

/**
 * Created by davidcosse on 06/02/15.
 */
public class ActionImportDto {

    protected String id;

    protected String topiaDiscriminator;

    protected String comment;

    protected String toolsCouplingCode;

    protected String practicedInterventionId;

    protected String effectiveInterventionId;

    protected String mainActionId;

    protected Double moisturePercent;

    protected Boolean exportedWaste;

    protected Double yealdTarget;

    protected String seedTypeName;

    protected String yealdUnitName;

    protected Double tillageDepth;

    protected String otherSettingTool;

    protected Double boiledQuantity;

    protected Double boiledQuantityPerTrip;

    protected Double tripFrequency;

    protected Boolean antiDriftNozzle;

    protected String quantityUnitEdiName;

    protected Double loadCapacity;

    protected String capacityUnitName;

    protected Boolean burial;

    protected Boolean localizedSpreading;

    protected Boolean landFilledWaste;

    protected Double waterQuantityMin;

    protected Double waterQuantityMax;

    protected Double waterQuantityAverage;

    protected Double waterQuantityMedian;

    protected Integer azoteQuantity;

    protected Double proportionOfTreatedSurface;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getTopiaDiscriminator() {
        return topiaDiscriminator;
    }

    public String getComment() {
        return comment;
    }

    public void setComment(String comment) {
        this.comment = comment;
    }

    public String getToolsCouplingCode() {
        return toolsCouplingCode;
    }

    public void setToolsCouplingCode(String toolsCouplingCode) {
        this.toolsCouplingCode = toolsCouplingCode;
    }

    public void setTopiaDiscriminator(String topiaDiscriminator) {
        this.topiaDiscriminator = topiaDiscriminator;
    }

    public String getPracticedInterventionId() {
        return practicedInterventionId;
    }

    public void setPracticedInterventionId(String practicedInterventionId) {
        this.practicedInterventionId = practicedInterventionId;
    }

    public String getEffectiveInterventionId() {
        return effectiveInterventionId;
    }

    public void setEffectiveInterventionId(String effectiveInterventionId) {
        this.effectiveInterventionId = effectiveInterventionId;
    }

    public String getMainActionId() {
        return mainActionId;
    }

    public void setMainActionId(String mainActionId) {
        this.mainActionId = mainActionId;
    }

    public Double getMoisturePercent() {
        return moisturePercent;
    }

    public void setMoisturePercent(Double moisturePercent) {
        this.moisturePercent = moisturePercent;
    }

    public Boolean getExportedWaste() {
        return exportedWaste;
    }

    public void setExportedWaste(Boolean exportedWaste) {
        this.exportedWaste = exportedWaste;
    }

    public Double getYealdTarget() {
        return yealdTarget;
    }

    public void setYealdTarget(Double yealdTarget) {
        this.yealdTarget = yealdTarget;
    }

    public String getSeedTypeName() {
        return seedTypeName;
    }

    public void setSeedTypeName(String seedTypeName) {
        this.seedTypeName = seedTypeName;
    }

    public String getYealdUnitName() {
        return yealdUnitName;
    }

    public void setYealdUnitName(String yealdUnitName) {
        this.yealdUnitName = yealdUnitName;
    }

    public Double getTillageDepth() {
        return tillageDepth;
    }

    public void setTillageDepth(Double tillageDepth) {
        this.tillageDepth = tillageDepth;
    }

    public String getOtherSettingTool() {
        return otherSettingTool;
    }

    public void setOtherSettingTool(String otherSettingTool) {
        this.otherSettingTool = otherSettingTool;
    }

    public Double getBoiledQuantity() {
        return boiledQuantity;
    }

    public void setBoiledQuantity(Double boiledQuantity) {
        this.boiledQuantity = boiledQuantity;
    }

    public Double getBoiledQuantityPerTrip() {
        return boiledQuantityPerTrip;
    }

    public void setBoiledQuantityPerTrip(Double boiledQuantityPerTrip) {
        this.boiledQuantityPerTrip = boiledQuantityPerTrip;
    }

    public Double getTripFrequency() {
        return tripFrequency;
    }

    public void setTripFrequency(Double tripFrequency) {
        this.tripFrequency = tripFrequency;
    }

    public Boolean getAntiDriftNozzle() {
        return antiDriftNozzle;
    }

    public void setAntiDriftNozzle(Boolean antiDriftNozzle) {
        this.antiDriftNozzle = antiDriftNozzle;
    }

    public String getQuantityUnitEdiName() {
        return quantityUnitEdiName;
    }

    public void setQuantityUnitEdiName(String quantityUnitEdiName) {
        this.quantityUnitEdiName = quantityUnitEdiName;
    }

    public Double getLoadCapacity() {
        return loadCapacity;
    }

    public void setLoadCapacity(Double loadCapacity) {
        this.loadCapacity = loadCapacity;
    }

    public String getCapacityUnitName() {
        return capacityUnitName;
    }

    public void setCapacityUnitName(String capacityUnitName) {
        this.capacityUnitName = capacityUnitName;
    }

    public Boolean getBurial() {
        return burial;
    }

    public void setBurial(Boolean burial) {
        this.burial = burial;
    }

    public Boolean getLocalizedSpreading() {
        return localizedSpreading;
    }

    public void setLocalizedSpreading(Boolean localizedSpreading) {
        this.localizedSpreading = localizedSpreading;
    }

    public Boolean getLandFilledWaste() {
        return landFilledWaste;
    }

    public void setLandFilledWaste(Boolean landFilledWaste) {
        this.landFilledWaste = landFilledWaste;
    }

    public Double getWaterQuantityMin() {
        return waterQuantityMin;
    }

    public void setWaterQuantityMin(Double waterQuantityMin) {
        this.waterQuantityMin = waterQuantityMin;
    }

    public Double getWaterQuantityMax() {
        return waterQuantityMax;
    }

    public void setWaterQuantityMax(Double waterQuantityMax) {
        this.waterQuantityMax = waterQuantityMax;
    }

    public Double getWaterQuantityAverage() {
        return waterQuantityAverage;
    }

    public void setWaterQuantityAverage(Double waterQuantityAverage) {
        this.waterQuantityAverage = waterQuantityAverage;
    }

    public Double getWaterQuantityMedian() {
        return waterQuantityMedian;
    }

    public void setWaterQuantityMedian(Double waterQuantityMedian) {
        this.waterQuantityMedian = waterQuantityMedian;
    }

    public Integer getAzoteQuantity() {
        return azoteQuantity;
    }

    public void setAzoteQuantity(Integer azoteQuantity) {
        this.azoteQuantity = azoteQuantity;
    }

    public Double getProportionOfTreatedSurface() {
        return proportionOfTreatedSurface;
    }

    public void setProportionOfTreatedSurface(Double proportionOfTreatedSurface) {
        this.proportionOfTreatedSurface = proportionOfTreatedSurface;
    }
}

==> agrosyst-cli-1.4.7-sources.jar: fr/inra/agrosyst/services/pz0import/action/ActionImportDto.java <==
package fr.inra.agrosyst.services.pz0import.action;

/*
 * #%L
 * Agrosyst :: Command Line Interface
 * $Id: ActionImportDto.java 4775 2015-02-10 15:13:34Z dcosse $
 * $HeadURL: https://svn.codelutin.com/agrosyst/tags/agrosyst-1.4.7/agrosyst-cli/src/main/java/fr/inra/agrosyst/services/pz0import/action/ActionImportDto.java $
 * %%
 * Copyright (C) 2013 - 2015 INRA
 * %%
 * INRA - Tous droits réservés
 * #L%
 */

/**
 * Created by davidcosse on 06/02/15.
 */
public class ActionImportDto {

    protected String id;

    protected String topiaDiscriminator;

    protected String comment;

    protected String toolsCouplingCode;

    protected String practicedInterventionId;

    protected String effectiveInterventionId;

    protected String mainActionId;

    protected Double moisturePercent;

    protected Boolean exportedWaste;

    protected Double yealdTarget;

    protected String seedTypeName;

    protected String yealdUnitName;

    protected Double tillageDepth;

    protected String otherSettingTool;

    protected Double boiledQuantity;

    protected Double boiledQuantityPerTrip;

    protected Double tripFrequency;

    protected Boolean antiDriftNozzle;

    protected String quantityUnitEdiName;

    protected Double loadCapacity;

    protected String capacityUnitName;

    protected Boolean burial;

    protected Boolean localizedSpreading;

    protected Boolean landFilledWaste;

    protected Double waterQuantityMin;

    protected Double waterQuantityMax;

    protected Double waterQuantityAverage;

    protected Double waterQuantityMedian;

    protected Integer azoteQuantity;

    protected Double proportionOfTreatedSurface;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getTopiaDiscriminator() {
        return topiaDiscriminator;
    }

    public String getComment() {
        return comment;
    }

    public void setComment(String comment) {
        this.comment = comment;
    }

    public String getToolsCouplingCode() {
        return toolsCouplingCode;
    }

    public void setToolsCouplingCode(String toolsCouplingCode) {
        this.toolsCouplingCode = toolsCouplingCode;
    }

    public void setTopiaDiscriminator(String topiaDiscriminator) {
        this.topiaDiscriminator = topiaDiscriminator;
    }

    public String getPracticedInterventionId() {
        return practicedInterventionId;
    }

    public void setPracticedInterventionId(String practicedInterventionId) {
        this.practicedInterventionId = practicedInterventionId;
    }

    public String getEffectiveInterventionId() {
        return effectiveInterventionId;
    }

    public void setEffectiveInterventionId(String effectiveInterventionId) {
        this.effectiveInterventionId = effectiveInterventionId;
    }

    public String getMainActionId() {
        return mainActionId;
    }

    public void setMainActionId(String mainActionId) {
        this.mainActionId = mainActionId;
    }

    public Double getMoisturePercent() {
        return moisturePercent;
    }

    public void setMoisturePercent(Double moisturePercent) {
        this.moisturePercent = moisturePercent;
    }

    public Boolean getExportedWaste() {
        return exportedWaste;
    }

    public void setExportedWaste(Boolean exportedWaste) {
        this.exportedWaste = exportedWaste;
    }

    public Double getYealdTarget() {
        return yealdTarget;
    }

    public void setYealdTarget(Double yealdTarget) {
        this.yealdTarget = yealdTarget;
    }

    public String getSeedTypeName() {
        return seedTypeName;
    }

    public void setSeedTypeName(String seedTypeName) {
        this.seedTypeName = seedTypeName;
    }

    public String getYealdUnitName() {
        return yealdUnitName;
    }

    public void setYealdUnitName(String yealdUnitName) {
        this.yealdUnitName = yealdUnitName;
    }

    public Double getTillageDepth() {
        return tillageDepth;
    }

    public void setTillageDepth(Double tillageDepth) {
        this.tillageDepth = tillageDepth;
    }

    public String getOtherSettingTool() {
        return otherSettingTool;
    }

    public void setOtherSettingTool(String otherSettingTool) {
        this.otherSettingTool = otherSettingTool;
    }

    public Double getBoiledQuantity() {
        return boiledQuantity;
    }

    public void setBoiledQuantity(Double boiledQuantity) {
        this.boiledQuantity = boiledQuantity;
    }

    public Double getBoiledQuantityPerTrip() {
        return boiledQuantityPerTrip;
    }

    public void setBoiledQuantityPerTrip(Double boiledQuantityPerTrip) {
        this.boiledQuantityPerTrip = boiledQuantityPerTrip;
    }

    public Double getTripFrequency() {
        return tripFrequency;
    }

    public void setTripFrequency(Double tripFrequency) {
        this.tripFrequency = tripFrequency;
    }

    public Boolean getAntiDriftNozzle() {
        return antiDriftNozzle;
    }

    public void setAntiDriftNozzle(Boolean antiDriftNozzle) {
        this.antiDriftNozzle = antiDriftNozzle;
    }

    public String getQuantityUnitEdiName() {
        return quantityUnitEdiName;
    }

    public void setQuantityUnitEdiName(String quantityUnitEdiName) {
        this.quantityUnitEdiName = quantityUnitEdiName;
    }

    public Double getLoadCapacity() {
        return loadCapacity;
    }

    public void setLoadCapacity(Double loadCapacity) {
        this.loadCapacity = loadCapacity;
    }

    public String getCapacityUnitName() {
        return capacityUnitName;
    }

    public void setCapacityUnitName(String capacityUnitName) {
        this.capacityUnitName = capacityUnitName;
    }

    public Boolean getBurial() {
        return burial;
    }

    public void setBurial(Boolean burial) {
        this.burial = burial;
    }

    public Boolean getLocalizedSpreading() {
        return localizedSpreading;
    }

    public void setLocalizedSpreading(Boolean localizedSpreading) {
        this.localizedSpreading = localizedSpreading;
    }

    public Boolean getLandFilledWaste() {
        return landFilledWaste;
    }

    public void setLandFilledWaste(Boolean landFilledWaste) {
        this.landFilledWaste = landFilledWaste;
    }

    public Double getWaterQuantityMin() {
        return waterQuantityMin;
    }

    public void setWaterQuantityMin(Double waterQuantityMin) {
        this.waterQuantityMin = waterQuantityMin;
    }

    public Double getWaterQuantityMax() {
        return waterQuantityMax;
    }

    public void setWaterQuantityMax(Double waterQuantityMax) {
        this.waterQuantityMax = waterQuantityMax;
    }

    public Double getWaterQuantityAverage() {
        return waterQuantityAverage;
    }

    public void setWaterQuantityAverage(Double waterQuantityAverage) {
        this.waterQuantityAverage = waterQuantityAverage;
    }

    public Double getWaterQuantityMedian() {
        return waterQuantityMedian;
    }

    public void setWaterQuantityMedian(Double waterQuantityMedian) {
        this.waterQuantityMedian = waterQuantityMedian;
    }

    public Integer getAzoteQuantity() {
        return azoteQuantity;
    }

    public void setAzoteQuantity(Integer azoteQuantity) {
        this.azoteQuantity = azoteQuantity;
    }

    public Double getProportionOfTreatedSurface() {
        return proportionOfTreatedSurface;
    }

    public void setProportionOfTreatedSurface(Double proportionOfTreatedSurface) {
        this.proportionOfTreatedSurface = proportionOfTreatedSurface;
    }
}
